@@ -1,7 +1,8 @@
 // Mast - load module
 #include "mastint.h"
 
-int MastLoadRom(char *Name,unsigned char **pRom,int *pRomLen)
+
+extern "C" int MastLoadRom(char *Name,unsigned char **pRom,int *pRomLen)
 {
   FILE *h=NULL; int Len=0;
   unsigned char *Mem=NULL;
